Daemon rucio-conveyor-finisher — Rucio 1.2 documentation

# Daemon rucio-conveyor-finisher

    usage: rucio-conveyor-finisher [-h] [--run-once] [--process PROCESS]
                                   [--total-processes TOTAL_PROCESSES]
                                   [--total-threads TOTAL_THREADS]
                                   [--db-bulk DB_BULK] [--bulk BULK]
                                   [--sleep-time SLEEP_TIME]
                                   [--activities ACTIVITIES [ACTIVITIES ...]]

## Named Arguments

`--run-once` | One iteration only Default: False
`--process` | Concurrency control: current processes number Default: 0
`--total-processes`
| Concurrency control: total number of processes Default: 1
`--total-threads`
| Concurrency control: total number of threads per process Default: 1
`--db-bulk` | Bulk control: number of transfers per db query Default: 1000
`--bulk` | Bulk control: number of requests Default: 100
`--sleep-time` | Seconds to sleep if few requests Default: 30
`--activities` | Explicit list of activities to include